
import setuptools

setuptools.setup(
    name="smart-hg-11",
    version="1.0",
    packages=setuptools.find_packages(),
    install_requires=['numpy==1.19.4', 'keras==2.4.3', 'tensorflow==2.4.0'],
)
